@@ -8,8 +8,8 @@ from m3_gar.models.reestr import (
     ReestrObjects,
 )
 from m3_gar.models.util import (
-    ParamsMixin,
     RegionCodeModelMixin,
+    add_params,
     make_fk,
 )
 
@@ -17,7 +17,7 @@ from m3_gar.models.util import (
 __all__ = ['Steads']
 
 
-class Steads(BaseSteads, ParamsMixin, RegionCodeModelMixin):
+class Steads(BaseSteads, RegionCodeModelMixin):
     """
     Сведения по земельным участкам
     """
@@ -31,3 +31,5 @@ class Steads(BaseSteads, ParamsMixin, RegionCodeModelMixin):
 
 make_fk(Steads, 'opertypeid', to=OperationTypes)
 make_fk(Steads, 'objectid', to=ReestrObjects)
+
+add_params(Steads, 'm3_gar.SteadsParams')
