@@ -3,7 +3,7 @@ from django.db import (
 )
 
 
-__all__ = ['Version', 'Status']
+__all__ = ['Version']
 
 
 class VersionManager(models.Manager):
@@ -23,14 +23,7 @@ class Version(models.Model):
     complete_xml_url = models.CharField(max_length=255)
     delta_xml_url = models.CharField(max_length=255, blank=True, null=True)
 
+    processed = models.BooleanField(verbose_name='Обработано', default=False)
+
     def __str__(self):
         return f'{self.ver} from {self.dumpdate}'
-
-
-class Status(models.Model):
-
-    table = models.CharField(primary_key=True, max_length=25)
-    ver = models.ForeignKey(Version, on_delete=models.CASCADE)
-
-    def __str__(self):
-        return self.table
